@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 use File::HomeDir;
 use HTTP::Daemon;
@@ -565,7 +565,7 @@ Gepok - PSGI server with built-in HTTPS support, Unix sockets, preforking
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
@@ -825,6 +825,12 @@ L<Starman> for "hello world" PSGI.
 I am using Gepok primarily with L<Perinci::Access::HTTP::Server> for serving
 remote API requests, in which HTTPS support is required.
 
+=head2 "Bad arg length for Socket::inet_ntoa, length is 16, should be 4" error
+
+At the time of this writing, L<HTTP::Daemon> (6.01) might throw this error
+message when receiving request. For patches/solutions to overcome this problem,
+see: https://rt.cpan.org/Ticket/Display.html?id=71395
+
 =head1 CREDITS
 
 Some code portion taken from Starman.
